.. _authors:

************************
Authors and contributors
************************

The following people have contributed code and/or ideas to the current version
of Alpaca. The institutional affiliations are those at the time of the
contribution, and may not be the current affiliation of a contributor.

* Cristiano André Köhler (orcid: 0000-0003-0503-5264) [1, 2]
* Danylo Ulianych (orcid: 0000-0003-3489-0542) [1]
* Michael Denker (orcid: 0000-0003-1255-7300) [1]

Alpaca logo designed by Angela Fischer (orcid: 0000-0002-9600-2646) [1].

1. Institute of Neuroscience and Medicine (INM-6) and Institute for Advanced Simulation (IAS-6) and JARA-Institute Brain Structure-Function Relationships (INM-10), Jülich Research Centre, Jülich, Germany
2. RWTH Aachen University

If we have somehow missed you off the list, we are very sorry. Please, let us
know.
